class Core {
    constructor(endpoint) {
        this.endpoint = endpoint;
    }

    static request(path, params, requestOptions = {}, callback = () => { }) {
        // 构建URL，如果是GET请求，将参数附加到URL中
        let url = this.endpoint + path;
        if (requestOptions.method === 'GET' && params) {
            const queryString = new URLSearchParams(params).toString();
            url += '?' + queryString;
        }

        // 设置默认的请求选项
        const options = {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
            },
            ...requestOptions,
        };

        // 如果请求不是GET，将参数作为请求体发送
        if (options.method !== 'GET' && params) {
            options.body = JSON.stringify(params);
        }

        // 发起请求
        fetch(url, options)
            .then(response => {
                if (!response.ok) {
                    throw new Error('网络请求出错：' + response.statusText);
                }
                return response.json();
            })
            .then(data => callback(null, data))
            .catch(error => callback(error));
    }

    // GET方法
    static get(path, params, callback) {
        this.request(path, params, { method: 'GET' }, callback);
    }

    // POST方法
    static post(path, params, callback) {
        this.request(path, params, { method: 'POST' }, callback);
    }

    // PUT方法
    static put(path, params, callback) {
        this.request(path, params, { method: 'PUT' }, callback);
    }

    // DELETE方法
    static delete(path, params, callback) {
        this.request(path, params, { method: 'DELETE' }, callback);
    }

    // PATCH方法
    static patch(path, params, callback) {
        this.request(path, params, { method: 'PATCH' }, callback);
    }
}

module.exports.Core = Core;